{% extends "base.html" %}
{% load i18n thumbnail %}
{% block meta_title %}{% trans "Events by category for " %}{{ agenda.title }}{% endblock %}

{% block document %}

	{% block article %}

		{% for event_category, events in events_by_categories.items %}

			{% include "agenda/event_category_list.html" with event_category=event_category events=events %}

		{% endfor %}


	{% endblock %}


{% endblock %}


