{% load i18n thumbnail %}

     <h4>{% trans "Agenda" %} {{ event_category.label }}</h4>

        {% for item in events %}
        <div class="list_item vcenter_container">
            <div class="vcenter_wrapper event-desc-wrapper">
                <div class="vcenter_content event-desc-content">

                    {% if item.linked_articles %}

                        {% with item.linked_articles.0 as article %}
                        {% thumbnail article.logo "120x120" as im %}
                        <a class="title" href="{{ article.get_absolute_url }}">
                           <img class="event-article-icon" src="{{ im.url }}" width="{{ im.width }}" height="{{ im.height }}">
                        </a>
                        {% endthumbnail %}

                        <a class="title" href="{{ article.get_absolute_url }}">{{ article.title }}</a><br/>
                        <span class="subtitle">{{ article.summary }}</span>

                        {% endwith %}

                    {% else %}

                        <a class="title" href="{{item.get_absolute_url}}">{{ item.title }}</a><br/>
                        <span class="subtitle">{{ item.description }}</span>

                    {% endif %}

                    {% for o in item.upcoming_occurrences%}
                    <ul>
                        <li>Le {{ o.start_time|date:"j F Y"}}
                            de {{ o.start_time|date:"H\hi" }} à {{ o.end_time|date:"H\hi" }}
                        </li>
                    </ul>
                    {% endfor %}


                </div>
            </div>
        </div>
        <hr>
        {% endfor %}