{% load remote %}

            <dl class="attr_table">

                {% if article.dated.all %}
                    {% for dated in article.dated.all %}
                        <dt>Date{{ dated.event.occurrence_set.all|pluralize }} agenda</dt>
                        <dd><div>{% for o in dated.event.occurrence_set.all %}
                            {{ o.start_time|date:"j F Y, \d\e H\hi" }} à {{ o.end_time|date:"H\hi" }}<br>
                            {% endfor %}
                            </div>
                        </dd>
                    {% endfor %}
                    
                    <br>
                {% endif %}

                <dt>Date de publication</dt>
                <dd>{{ article.created|date:"j F Y" }}</dd>

                <dt>Dernière mise à jour</dt>
                <dd>{{ article.modified|date:"j F Y" }}</dd>

                {% if article.person or article.remote_person_label %}
                    <dt>Auteur</dt>
                    {% local_or_remote uri article person as author_uri %}
                    {% local_or_remote label article person as author_label %}
                    <dd>{% if author_uri %}<a href="{{author_uri}}">{% endif %}
                        {{ author_label }}
                        {% if author_uri %}</a>{% endif %}</dd>
                {% endif %}

                {% if article.organization or article.remote_organization_label %}
                    <dt>Auteur</dt>
                    {% local_or_remote uri article organization as org_uri %}
                    {% local_or_remote label article organization as org_label %}
                    <dd>{% if org_uri %}<a href="{{org_uri}}">{% endif %}
                        {{ org_label }}
                        {% if org_uri %}</a>{% endif %}</dd>
                {% endif %}

                {% if article.tags.all %}
                    <dt>Mots-clés</dt>
                    <dd>{% for tag in article.tags.all %}
                        <a href="{{ tag.get_absolute_url }}">{{ tag }}</a>{% if not forloop.last %}, {% endif %}
                        {% endfor %}</dd>
                {% endif %}

            </dl>