<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
    <link rel="stylesheet" href="style.css" />
    <title>{% block title %} First {% endblock %}</title>
</head>

<body>
    <h1> {{ banner }} </h1>
    <div> {{ intro }} </div>
    <div id="content">
        {% block content %}{% endblock %}
    </div>

</body>
</html>