{% extends "base.html" %}
{% load i18n coop_edition coop_navigation %}

{% block meta_title %}{{article.title}}{% endblock %}

{% block jquery_declaration %}
{{ block.super }}
{% if_cms_edition %}{% cms_form_media %}{% endif %}
{% endblock %}

{% block document %}

    {% block article %}

        <ul class="breadcrumb">
       <li><a href="/">Accueil</a> <span class="divider">/</span></li>
        {% navigation_breadcrumb article li_template="coop_cms/breadcrumb_li_template.html" %}
        </ul>

    {% cms_edit article logo_size=200 %}

            <h2 id="title">{{article.title}}</h2>
            <div class="content">

            <div class="summary">{{ article.summary }}</div>

                <span id="logo" class="the-logo">{{ article.logo }}</span>
                {{ article.content }}
            </div>


    {% end_cms_edit %}
    {% if_cms_edition %}
        {% include "coop_cms/_article_publication.html" %}
    {% endif %}
    {% endblock %}

    {% if article.isSection %}
        {% include "coop_cms/article_children.html" %}
    {% endif %}

    {% include "coop_cms/article_metadata.html" %}

{% endblock %}

