{% load i18n %}
        <tr><th>{{ event_form.event_type.label_tag }}</th>
            <td>{{ event_form.event_type.errors }}
                {{ event_form.event_type }}</td></tr>
        <tr><th>{{ event_form.title.label_tag }}</th>
            <td>{{ event_form.title.errors }}
                {{ event_form.title }}</td></tr>
        <tr><th>{{ event_form.description.label_tag }}</th>
            <td>{{ event_form.description }}</td></tr>
