{% extends "base.html" %}


{% block content %}
<ul>
    <li> voir la liste des adhérents déjà inscrits <a href="current/detail">ici</a>
    <li> je m'identifie <a href="member">connect </a>
    </li>

    <li> je régle <a href="pay">payement</a>
    </li>    
</ul>

{% endblock %}
