{% extends "base.html" %}


{% block content %}

{% if members %}
    <div> Les membres sont listés ci-dessous : </div>

    <ul>
    {% for member in members %}
        <li> {{member.name}} </li>
    {% endfor %}
    </ul>
{% else %}
    <p>Désolé il n'y a pas d'adhérent pour la period {{period}}.</p>
{% endif %}



{% if validMembers %}
    <div> Les membres VALIDES sont listés ici :
    </div>
    <ul>
    {% for member in validMembers %}
        <li> {{member.name}} </li>
    {% endfor %}
    </ul>
{% else %}
    <p>Désolé il n'y a pas d'adhérent VALID pour la period {{period}}.</p>
{% endif %}


{% endblock %}
