{% extends "base.html" %}
{% load coop_edition thumbnail %}
{% block meta_title %}{{org_category.label}}{% endblock %}

{% block document %}

    {% block article %}


    {% cms_edit org_category %}

     <h3>{{ org_category.label }}</h3>
     <hr>

    <p class="description">{{ org_category.description|safe }}</p>

    {% end_cms_edit %}

        <div id="content">
            <div class="grid_12 grid">

                {% for item in org_list %}
                <div class="list_item vcenter_container">
                    <div class="vcenter_wrapper org-desc-wrapper">
                        <div class="vcenter_content org-desc-content">
                            {% thumbnail item.logo "80x80" as im %}
                            <a class="title" href="{{item.get_absolute_url}}">
                               <img class="org-list-icon" src="{{ im.url }}" width="{{ im.width }}" height="{{ im.height }}">
                            </a>
                            {% endthumbnail %}
                            <a class="title" href="{{item.get_absolute_url}}">{{ item.title }}</a><br/>
                            {% if item.subtitle %}<span class="subtitle">{{ item.subtitle }}</span>{% endif %}
                        </div>
                    </div>
                </div>
                {% endfor %}


            </div>
        </div>
    {% endblock %}

{% endblock %}

